var searchData=
[
  ['name_0',['Name',['../structjs_stream_source.html#a7d9e5c064866b3f0b5601193c5885ec3',1,'jsStreamSource::Name()'],['../structjs_stream_config.html#a7fe3d5086f1c660a6999ae40ecd370e5',1,'jsStreamConfig::Name()'],['../structjs_peer_info.html#abf29230ce03a1c14d50227663e07de6a',1,'jsPeerInfo::Name()'],['../structjs_cluster_info.html#a2e13d7ec417574100c938c4df78e5484',1,'jsClusterInfo::Name()'],['../structjs_stream_source_info.html#a6db3c6ff8a465a45f8bd5c7bdf5f6c04',1,'jsStreamSourceInfo::Name()'],['../structjs_consumer_config.html#a201217d93cfed17eb4d3e2d9579b826a',1,'jsConsumerConfig::Name()'],['../structjs_consumer_info.html#a9359aea7cd05a27b2a15f8a35cdb1008',1,'jsConsumerInfo::Name()'],['../structjs_tier.html#a1ed542b9acccbe7761839f33c43053a6',1,'jsTier::Name()']]],
  ['nats_2eh_1',['nats.h',['../nats_8h.html',1,'']]],
  ['nats_5faddress_5fmissing_2',['NATS_ADDRESS_MISSING',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ae1d2c1366dbed428f6589f057acc507d',1,'status.h']]],
  ['nats_5fcheckcompatibility_3',['nats_CheckCompatibility',['../group__library_group.html#ga8c2ad4df801bd9d11564587ed3a7081e',1,'nats.h']]],
  ['nats_5fclose_4',['nats_Close',['../group__library_group.html#gae75131e0ce4e5b89d0f82ea7892f112e',1,'nats.h']]],
  ['nats_5fcloseandwait_5',['nats_CloseAndWait',['../group__library_group.html#gaf75bb5b38bf32e6a8f43e54068625903',1,'nats.h']]],
  ['nats_5fconn_5fstatus_5fclosed_6',['NATS_CONN_STATUS_CLOSED',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51aa78753a4de2d0379078bb09cdc1acdb2',1,'status.h']]],
  ['nats_5fconn_5fstatus_5fconnected_7',['NATS_CONN_STATUS_CONNECTED',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51a0dafab74b55f98cfc1d00e4d1ef38725',1,'status.h']]],
  ['nats_5fconn_5fstatus_5fconnecting_8',['NATS_CONN_STATUS_CONNECTING',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51a7e4d95cb29122f06e17ca4aff55cc736',1,'status.h']]],
  ['nats_5fconn_5fstatus_5fdisconnected_9',['NATS_CONN_STATUS_DISCONNECTED',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51a08f92960811d1ff05b91a0870b4ecb92',1,'status.h']]],
  ['nats_5fconn_5fstatus_5fdraining_5fpubs_10',['NATS_CONN_STATUS_DRAINING_PUBS',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51ac6b8b7f138f6ca285fe1f4da707b2100',1,'status.h']]],
  ['nats_5fconn_5fstatus_5fdraining_5fsubs_11',['NATS_CONN_STATUS_DRAINING_SUBS',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51ab6f9d121707673a61cbe2c591f64fbf1',1,'status.h']]],
  ['nats_5fconn_5fstatus_5freconnecting_12',['NATS_CONN_STATUS_RECONNECTING',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51acfdc4826e08ce4b59f901952038e9206',1,'status.h']]],
  ['nats_5fconnection_5fauth_5ffailed_13',['NATS_CONNECTION_AUTH_FAILED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a473ea6cfa03490838fafee8730b48a2a',1,'status.h']]],
  ['nats_5fconnection_5fclosed_14',['NATS_CONNECTION_CLOSED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a476d7bcf9a593b749e435f20a9156eff',1,'status.h']]],
  ['nats_5fconnection_5fdisconnected_15',['NATS_CONNECTION_DISCONNECTED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80abef517217119e8446a8e3382e1f37eb3',1,'status.h']]],
  ['nats_5fdefault_5furl_16',['NATS_DEFAULT_URL',['../nats_8h.html#a911c54900b46b968205871cd9f68d36c',1,'nats.h']]],
  ['nats_5fdraining_17',['NATS_DRAINING',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a07fdbda44f43cef9866a75b25053c2ae',1,'status.h']]],
  ['nats_5ferr_18',['NATS_ERR',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a40a08ae6ae17deaf390b1d0d7550791c',1,'status.h']]],
  ['nats_5fextern_19',['NATS_EXTERN',['../nats_8h.html#a3bc1b3fe7f64083e60c7c3b93f205bad',1,'nats.h']]],
  ['nats_5ffailed_5fto_5finitialize_20',['NATS_FAILED_TO_INITIALIZE',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a7cb64f52c8d91d6ade3db6bc82a96c42',1,'status.h']]],
  ['nats_5fgetlasterror_21',['nats_GetLastError',['../group__library_group.html#gadecfd49a58b581dbba40da77b195fd85',1,'nats.h']]],
  ['nats_5fgetlasterrorstack_22',['nats_GetLastErrorStack',['../group__library_group.html#gaca24172e1b97ca01cee29ca437f5702e',1,'nats.h']]],
  ['nats_5fgetversion_23',['nats_GetVersion',['../group__library_group.html#ga0d8c3df1c0c4a3d340d8ff81355fb1e8',1,'nats.h']]],
  ['nats_5fgetversionnumber_24',['nats_GetVersionNumber',['../group__library_group.html#ga5fbbaa19b0290b654d2669a05bd512e8',1,'nats.h']]],
  ['nats_5fillegal_5fstate_25',['NATS_ILLEGAL_STATE',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a9bb78b4f245d2870040d25c450febd4b',1,'status.h']]],
  ['nats_5finsufficient_5fbuffer_26',['NATS_INSUFFICIENT_BUFFER',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a317fb9be1a80f6b1877f96a9a2db16ad',1,'status.h']]],
  ['nats_5finvalid_5farg_27',['NATS_INVALID_ARG',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a71b57630aebf5c20eecdab832c2a9235',1,'status.h']]],
  ['nats_5finvalid_5fqueue_5fname_28',['NATS_INVALID_QUEUE_NAME',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a8a0d239cfdfa30fe730afea65941779b',1,'status.h']]],
  ['nats_5finvalid_5fsubject_29',['NATS_INVALID_SUBJECT',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a790c08a7d33e3aefce07c04120c4c19e',1,'status.h']]],
  ['nats_5finvalid_5fsubscription_30',['NATS_INVALID_SUBSCRIPTION',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a273e92a0ff3b7eaf946b4b7fa6cc6c6c',1,'status.h']]],
  ['nats_5finvalid_5ftimeout_31',['NATS_INVALID_TIMEOUT',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a827072fc245a99a60691e1e4b173ca86',1,'status.h']]],
  ['nats_5fio_5ferror_32',['NATS_IO_ERROR',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a44e8b2590369fb01a1479719c97c2b6f',1,'status.h']]],
  ['nats_5fline_5ftoo_5flong_33',['NATS_LINE_TOO_LONG',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a85c29dbfa6b06ffef3418cc9947ffff7',1,'status.h']]],
  ['nats_5fmax_5fdelivered_5fmsgs_34',['NATS_MAX_DELIVERED_MSGS',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a9a6f40b7803639ac18bdf532e93e5ad5',1,'status.h']]],
  ['nats_5fmax_5fpayload_35',['NATS_MAX_PAYLOAD',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80af820300473609092a3e97a71b5af9ff9',1,'status.h']]],
  ['nats_5fmismatch_36',['NATS_MISMATCH',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a22fa4802a34bac497f23e269a20a52f2',1,'status.h']]],
  ['nats_5fmissed_5fheartbeat_37',['NATS_MISSED_HEARTBEAT',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a37d80c8232775339a32805fe93e0ea7f',1,'status.h']]],
  ['nats_5fno_5fmemory_38',['NATS_NO_MEMORY',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a62ff6f5cc64399631defc0119731b514',1,'status.h']]],
  ['nats_5fno_5fresponders_39',['NATS_NO_RESPONDERS',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80aab97324e40ccfe1360080c651c330e62',1,'status.h']]],
  ['nats_5fno_5fserver_40',['NATS_NO_SERVER',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a47034d8889521bbd300f45fdc19e1127',1,'status.h']]],
  ['nats_5fno_5fserver_5fsupport_41',['NATS_NO_SERVER_SUPPORT',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a8a4e298931ba0698a72e397b1b57c885',1,'status.h']]],
  ['nats_5fnot_5ffound_42',['NATS_NOT_FOUND',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ad0229a12b17d3d12a28efed6213720d8',1,'status.h']]],
  ['nats_5fnot_5finitialized_43',['NATS_NOT_INITIALIZED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ae47047f2fac5f2f2a434fc501e5c3d4e',1,'status.h']]],
  ['nats_5fnot_5fpermitted_44',['NATS_NOT_PERMITTED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ac3abc147873fe999c86431f9222eebf5',1,'status.h']]],
  ['nats_5fnot_5fyet_5fconnected_45',['NATS_NOT_YET_CONNECTED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a49a1ea653ce112b3c53eedebcd60811d',1,'status.h']]],
  ['nats_5fnow_46',['nats_Now',['../group__library_group.html#gaa3c10ba3ae001595007ad0dc5dccc15e',1,'nats.h']]],
  ['nats_5fnowinnanoseconds_47',['nats_NowInNanoSeconds',['../group__library_group.html#gacf5e423920d6a647df3bbf7de39d5223',1,'nats.h']]],
  ['nats_5fok_48',['NATS_OK',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a9cee6c417868ecaa69f99ff4f6576990',1,'status.h']]],
  ['nats_5fopen_49',['nats_Open',['../group__library_group.html#ga4a26d4caecb23348f6eee862c95fee7d',1,'nats.h']]],
  ['nats_5fprintlasterrorstack_50',['nats_PrintLastErrorStack',['../group__library_group.html#ga5fab3b18c4fe3630254483575f6066f4',1,'nats.h']]],
  ['nats_5fprotocol_5ferror_51',['NATS_PROTOCOL_ERROR',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a113ffbe9a1f243582c38ebd876cb736d',1,'status.h']]],
  ['nats_5freleasethreadmemory_52',['nats_ReleaseThreadMemory',['../group__library_group.html#gafe171baefa00a85b77205116e9f3e48a',1,'nats.h']]],
  ['nats_5fsecure_5fconnection_5frequired_53',['NATS_SECURE_CONNECTION_REQUIRED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80abc76f1b31fdac4525583cc19588240dc',1,'status.h']]],
  ['nats_5fsecure_5fconnection_5fwanted_54',['NATS_SECURE_CONNECTION_WANTED',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a0aa3d1e18a2a217149fa8b1a306c9b08',1,'status.h']]],
  ['nats_5fsetmessagedeliverypoolsize_55',['nats_SetMessageDeliveryPoolSize',['../group__library_group.html#gab21e94ce7a7d226611ea2c05914cf19d',1,'nats.h']]],
  ['nats_5fsign_56',['nats_Sign',['../group__library_group.html#gaf781f246e2e0ab24623ca667c48dc3ba',1,'nats.h']]],
  ['nats_5fsleep_57',['nats_Sleep',['../group__library_group.html#gad5040264cd4b1404956babf3c03a4f09',1,'nats.h']]],
  ['nats_5fslow_5fconsumer_58',['NATS_SLOW_CONSUMER',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ae93ff5b7fe31f8570308385d92d317b0',1,'status.h']]],
  ['nats_5fssl_5ferror_59',['NATS_SSL_ERROR',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a892183c32b4929388bb75dc62230ddf3',1,'status.h']]],
  ['nats_5fstale_5fconnection_60',['NATS_STALE_CONNECTION',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80aa76d5e3ce051bc7510be90e73663c93d',1,'status.h']]],
  ['nats_5fsys_5ferror_61',['NATS_SYS_ERROR',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80a984189ec4cfe3e7647268c99f7e49ec9',1,'status.h']]],
  ['nats_5ftimeout_62',['NATS_TIMEOUT',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80ab88994c9ea9889ac4d9d656d62f550ed',1,'status.h']]],
  ['natsconnection_63',['natsConnection',['../group__types_group.html#gaf88dca0a18efb5c5e994d265a9f04aec',1,'nats.h']]],
  ['natsconnection_5fbuffered_64',['natsConnection_Buffered',['../group__conn_mgt_group.html#ga0433159e518540ff874c4026fe9cd0c5',1,'nats.h']]],
  ['natsconnection_5fclose_65',['natsConnection_Close',['../group__conn_mgt_group.html#ga19e204d27a232e2d4334301fc002b2ed',1,'nats.h']]],
  ['natsconnection_5fconnect_66',['natsConnection_Connect',['../group__conn_mgt_group.html#ga740be1ba16a8570eb98ef6755ebf52ce',1,'nats.h']]],
  ['natsconnection_5fconnectto_67',['natsConnection_ConnectTo',['../group__conn_mgt_group.html#gafb83c8d7970ba68be0e6c40c38cdfde4',1,'nats.h']]],
  ['natsconnection_5fdestroy_68',['natsConnection_Destroy',['../group__conn_mgt_group.html#gafda2f702276fb0ac301efac10df09495',1,'nats.h']]],
  ['natsconnection_5fdrain_69',['natsConnection_Drain',['../group__conn_mgt_group.html#ga59bdc4ad9fea2053f5d3841f6b83f88b',1,'nats.h']]],
  ['natsconnection_5fdraintimeout_70',['natsConnection_DrainTimeout',['../group__conn_mgt_group.html#gae06fe6f5933f216d6d93645a122a7dd4',1,'nats.h']]],
  ['natsconnection_5fflush_71',['natsConnection_Flush',['../group__conn_mgt_group.html#ga1c98f8d89bb8e20ea8621e860a90267f',1,'nats.h']]],
  ['natsconnection_5fflushtimeout_72',['natsConnection_FlushTimeout',['../group__conn_mgt_group.html#ga85915ef0c8b87993be1b076099d6a7c1',1,'nats.h']]],
  ['natsconnection_5fgetclientid_73',['natsConnection_GetClientID',['../group__conn_mgt_group.html#ga747513ba6ab63fdf9a72bfc8025a14ba',1,'nats.h']]],
  ['natsconnection_5fgetclientip_74',['natsConnection_GetClientIP',['../group__conn_mgt_group.html#gadafcfeeeac2733c7119981ab97b7103d',1,'nats.h']]],
  ['natsconnection_5fgetconnectedserverid_75',['natsConnection_GetConnectedServerId',['../group__conn_mgt_group.html#ga48cee9ea1cdc9fc2770de2f9f0fd1ccf',1,'nats.h']]],
  ['natsconnection_5fgetconnectedurl_76',['natsConnection_GetConnectedUrl',['../group__conn_mgt_group.html#gaf623280407c43ade02285005f0642e6d',1,'nats.h']]],
  ['natsconnection_5fgetdiscoveredservers_77',['natsConnection_GetDiscoveredServers',['../group__conn_mgt_group.html#gad25c77be0873495412c90a73fe450708',1,'nats.h']]],
  ['natsconnection_5fgetlasterror_78',['natsConnection_GetLastError',['../group__conn_mgt_group.html#gab6cfa9cb6857ae10f096a94f5e244e63',1,'nats.h']]],
  ['natsconnection_5fgetlocalipandport_79',['natsConnection_GetLocalIPAndPort',['../group__conn_mgt_group.html#ga761095a42374b4dafa178df7d7652dd5',1,'nats.h']]],
  ['natsconnection_5fgetmaxpayload_80',['natsConnection_GetMaxPayload',['../group__conn_mgt_group.html#ga68e7149f7ff1cc4989b3f795fa7e76d9',1,'nats.h']]],
  ['natsconnection_5fgetrtt_81',['natsConnection_GetRTT',['../group__conn_mgt_group.html#gaa3fd27e6e7d8131e679d4f10e201c435',1,'nats.h']]],
  ['natsconnection_5fgetservers_82',['natsConnection_GetServers',['../group__conn_mgt_group.html#gaf4ee7262e35e44c40ad5dfe9240db76b',1,'nats.h']]],
  ['natsconnection_5fgetstats_83',['natsConnection_GetStats',['../group__conn_mgt_group.html#ga68821a8ae1176096b5afef7fdc7947ec',1,'nats.h']]],
  ['natsconnection_5fhasheadersupport_84',['natsConnection_HasHeaderSupport',['../group__conn_mgt_group.html#gad765b80ae8e1a06a7a942cccf29f042a',1,'nats.h']]],
  ['natsconnection_5fisclosed_85',['natsConnection_IsClosed',['../group__conn_mgt_group.html#ga530f0f1c75c58a81aae1a59f15b46d9f',1,'nats.h']]],
  ['natsconnection_5fisdraining_86',['natsConnection_IsDraining',['../group__conn_mgt_group.html#ga15a0f8aa9a6f621535d01593a4c8edd5',1,'nats.h']]],
  ['natsconnection_5fisreconnecting_87',['natsConnection_IsReconnecting',['../group__conn_mgt_group.html#ga5aa349fc3895dde772671b324b07a688',1,'nats.h']]],
  ['natsconnection_5fjetstream_88',['natsConnection_JetStream',['../group__js_group.html#ga8ed08b0fe1074b1e490291f0af2cb03f',1,'nats.h']]],
  ['natsconnection_5fprocessreadevent_89',['natsConnection_ProcessReadEvent',['../group__conn_mgt_group.html#gaa89c06e30e19ff361125bfc9114d89a8',1,'nats.h']]],
  ['natsconnection_5fprocesswriteevent_90',['natsConnection_ProcessWriteEvent',['../group__conn_mgt_group.html#gad81b603b84c0180aefc6d5ebad7f2a47',1,'nats.h']]],
  ['natsconnection_5fpublish_91',['natsConnection_Publish',['../group__conn_pub_group.html#gac0b9f7759ecc39b8d77807b94254f9b4',1,'nats.h']]],
  ['natsconnection_5fpublishmsg_92',['natsConnection_PublishMsg',['../group__conn_pub_group.html#ga74511acd87385931112c45c48c2a14ba',1,'nats.h']]],
  ['natsconnection_5fpublishrequest_93',['natsConnection_PublishRequest',['../group__conn_pub_group.html#gaaaa3d75ffec2dcdc6bf905cdb1eee59e',1,'nats.h']]],
  ['natsconnection_5fpublishrequeststring_94',['natsConnection_PublishRequestString',['../group__conn_pub_group.html#gaafca9a8294e81a5a9979e762931e56c5',1,'nats.h']]],
  ['natsconnection_5fpublishstring_95',['natsConnection_PublishString',['../group__conn_pub_group.html#gad09a717c20de4cf0e2a21dcfd9ce6c64',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribe_96',['natsConnection_QueueSubscribe',['../group__conn_sub_group.html#ga3c9fee2775130786ef62f1cbeb191a48',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribesync_97',['natsConnection_QueueSubscribeSync',['../group__conn_sub_group.html#ga68630ea7c4bbdc7f8cd62058b41fb476',1,'nats.h']]],
  ['natsconnection_5fqueuesubscribetimeout_98',['natsConnection_QueueSubscribeTimeout',['../group__conn_sub_group.html#ga96fa115fd5b2ef7658884da80714b91c',1,'nats.h']]],
  ['natsconnection_5frequest_99',['natsConnection_Request',['../group__conn_pub_group.html#gaf4b4a022f9c21fc269b87c000330c5a7',1,'nats.h']]],
  ['natsconnection_5frequestmsg_100',['natsConnection_RequestMsg',['../group__conn_pub_group.html#ga052de4b75b3b69ccd8d20eb4861b801d',1,'nats.h']]],
  ['natsconnection_5frequeststring_101',['natsConnection_RequestString',['../group__conn_pub_group.html#ga4bb5105df6a3efd2088e6be0fdf6b31f',1,'nats.h']]],
  ['natsconnection_5fsign_102',['natsConnection_Sign',['../group__conn_mgt_group.html#ga6960cfdbaac3b8759784f352d4c264f8',1,'nats.h']]],
  ['natsconnection_5fstatus_103',['natsConnection_Status',['../group__conn_mgt_group.html#ga33fa209522e5e0226b5b7c7d720a3b98',1,'nats.h']]],
  ['natsconnection_5fsubscribe_104',['natsConnection_Subscribe',['../group__conn_sub_group.html#gaefab965b5645798d47f9244f2b3fe3fb',1,'nats.h']]],
  ['natsconnection_5fsubscribesync_105',['natsConnection_SubscribeSync',['../group__conn_sub_group.html#ga17574d5165f7e285462e3d3b2709edf4',1,'nats.h']]],
  ['natsconnection_5fsubscribetimeout_106',['natsConnection_SubscribeTimeout',['../group__conn_sub_group.html#gacb2c83b58b7909715424cbc327fdd404',1,'nats.h']]],
  ['natsconnectionhandler_107',['natsConnectionHandler',['../group__callbacks_group.html#gacdef6aff3e47953f19e35857ab8e274c',1,'nats.h']]],
  ['natsconnstatus_108',['natsConnStatus',['../status_8h.html#a6d667c1f8dd289a7e0f39bf10e800b51',1,'status.h']]],
  ['natscustomreconnectdelayhandler_109',['natsCustomReconnectDelayHandler',['../group__callbacks_group.html#ga3353d4b92851c52121f65aaf0684cba4',1,'nats.h']]],
  ['natserrhandler_110',['natsErrHandler',['../group__callbacks_group.html#ga9e511dffa471dfb971b7dd2b12329626',1,'nats.h']]],
  ['natsevloop_5fattach_111',['natsEvLoop_Attach',['../group__callbacks_group.html#ga245eab0a01a485e40fba267f84ec037f',1,'nats.h']]],
  ['natsevloop_5fdetach_112',['natsEvLoop_Detach',['../group__callbacks_group.html#gab63dee7f7012ba11ae20b76dbc36f2d0',1,'nats.h']]],
  ['natsevloop_5freadaddremove_113',['natsEvLoop_ReadAddRemove',['../group__callbacks_group.html#gaea4c125ecfb43eaf43da20e8444c2aaa',1,'nats.h']]],
  ['natsevloop_5fwriteaddremove_114',['natsEvLoop_WriteAddRemove',['../group__callbacks_group.html#ga2bb5dd2d821ca5bbc0488f7e6aceed17',1,'nats.h']]],
  ['natsinbox_115',['natsInbox',['../group__types_group.html#ga206c3d4d6f4f6f96fd2cae53a3df31c1',1,'nats.h']]],
  ['natsinbox_5fcreate_116',['natsInbox_Create',['../group__inbox_group.html#gaa1ec779a0b7ead54b78da05533848b6d',1,'nats.h']]],
  ['natsinbox_5fdestroy_117',['natsInbox_Destroy',['../group__inbox_group.html#gabd6444fb8f28afb9c2b6645945f46cfe',1,'nats.h']]],
  ['natslibevent_5fattach_118',['natsLibevent_Attach',['../group__libevent_functions.html#ga30c00f21a5251ee9fde09c1f2b429cd2',1,'libevent.h']]],
  ['natslibevent_5fdetach_119',['natsLibevent_Detach',['../group__libevent_functions.html#gaac76f5937329a8650f69c6bd8af36cd5',1,'libevent.h']]],
  ['natslibevent_5finit_120',['natsLibevent_Init',['../group__libevent_functions.html#ga195d269473332931fd0fede0bac3309e',1,'libevent.h']]],
  ['natslibevent_5fread_121',['natsLibevent_Read',['../group__libevent_functions.html#ga8a14ce23b4f6ba3bf63369961f9a5552',1,'libevent.h']]],
  ['natslibevent_5fwrite_122',['natsLibevent_Write',['../group__libevent_functions.html#ga7ac99f326a59e5663ff66f5023c87091',1,'libevent.h']]],
  ['natslibuv_5fattach_123',['natsLibuv_Attach',['../group__libuv_functions.html#ga86ac71cffe752effd7397740d80c3c42',1,'libuv.h']]],
  ['natslibuv_5fdetach_124',['natsLibuv_Detach',['../group__libuv_functions.html#ga8df663525fb59b882a0f3bd563083dc7',1,'libuv.h']]],
  ['natslibuv_5finit_125',['natsLibuv_Init',['../group__libuv_functions.html#ga5d4b677cbe1cd132c37bc56dbfc6949e',1,'libuv.h']]],
  ['natslibuv_5fread_126',['natsLibuv_Read',['../group__libuv_functions.html#ga85c722b2d2699a954362b20528f0aaac',1,'libuv.h']]],
  ['natslibuv_5fsetthreadlocalloop_127',['natsLibuv_SetThreadLocalLoop',['../group__libuv_functions.html#ga1baf4a20b138dcf00807a8b830f4e02d',1,'libuv.h']]],
  ['natslibuv_5fwrite_128',['natsLibuv_Write',['../group__libuv_functions.html#gafaa633c9067f485f330b72644277b07d',1,'libuv.h']]],
  ['natsmsg_129',['natsMsg',['../group__types_group.html#gadcab54026c4ed78f344ce03ce31bb61a',1,'nats.h']]],
  ['natsmsg_5fack_130',['natsMsg_Ack',['../group__js_msg.html#gae454fb7e7097a3cd3362cb49ef8a3c84',1,'nats.h']]],
  ['natsmsg_5facksync_131',['natsMsg_AckSync',['../group__js_msg.html#gafb899ebf8e89b3a858fe20f7853635a7',1,'nats.h']]],
  ['natsmsg_5fcreate_132',['natsMsg_Create',['../group__msg_group.html#ga098e4fec1c5a71c00a0d092fbd6d1a21',1,'nats.h']]],
  ['natsmsg_5fdestroy_133',['natsMsg_Destroy',['../group__msg_group.html#ga9e9590018284939f43f60964283f33ae',1,'nats.h']]],
  ['natsmsg_5fgetdata_134',['natsMsg_GetData',['../group__msg_group.html#ga523364451fd92534e754054266196e59',1,'nats.h']]],
  ['natsmsg_5fgetdatalength_135',['natsMsg_GetDataLength',['../group__msg_group.html#ga25b69066ae50287e178aaf4f70f7d3de',1,'nats.h']]],
  ['natsmsg_5fgetmetadata_136',['natsMsg_GetMetaData',['../group__js_msg.html#gacf48e59038fab35849e9dc6f8fcf6328',1,'nats.h']]],
  ['natsmsg_5fgetreply_137',['natsMsg_GetReply',['../group__msg_group.html#ga880535362c91b3e405792aa66ff945b6',1,'nats.h']]],
  ['natsmsg_5fgetsequence_138',['natsMsg_GetSequence',['../group__js_msg.html#ga819be2990ec20b964aa574b5331d7f2e',1,'nats.h']]],
  ['natsmsg_5fgetsubject_139',['natsMsg_GetSubject',['../group__msg_group.html#gad7cad38946648e3047aa0665a3dd230a',1,'nats.h']]],
  ['natsmsg_5fgettime_140',['natsMsg_GetTime',['../group__js_msg.html#gab4850497c5481f5ec6eb1fcdb43646f5',1,'nats.h']]],
  ['natsmsg_5finprogress_141',['natsMsg_InProgress',['../group__js_msg.html#gae1e0beb19cd76e2f69e6415c41c9bb39',1,'nats.h']]],
  ['natsmsg_5fisnoresponders_142',['natsMsg_IsNoResponders',['../group__msg_group.html#ga43aa4a8e4b93725b4876ee2677e19c7b',1,'nats.h']]],
  ['natsmsg_5fnak_143',['natsMsg_Nak',['../group__js_msg.html#gac271b874154301da9759f9ac05768b47',1,'nats.h']]],
  ['natsmsg_5fnakwithdelay_144',['natsMsg_NakWithDelay',['../group__js_msg.html#gac0697389fa60a3c4725e53cd23ada7bd',1,'nats.h']]],
  ['natsmsg_5fterm_145',['natsMsg_Term',['../group__js_msg.html#gae84d21e4388255e9d990e53c9f67e7c4',1,'nats.h']]],
  ['natsmsghandler_146',['natsMsgHandler',['../group__callbacks_group.html#gad1a5ac566893e13dc8c81ac0e9c87afe',1,'nats.h']]],
  ['natsmsgheader_5fadd_147',['natsMsgHeader_Add',['../group__msg_group.html#ga2b641ec3b1745604d7de1102e472254b',1,'nats.h']]],
  ['natsmsgheader_5fdelete_148',['natsMsgHeader_Delete',['../group__msg_group.html#gac78ca02dc93d05cae837ced6386408f1',1,'nats.h']]],
  ['natsmsgheader_5fget_149',['natsMsgHeader_Get',['../group__msg_group.html#gab3349f0b0ce721b340d5c0753c90ee18',1,'nats.h']]],
  ['natsmsgheader_5fkeys_150',['natsMsgHeader_Keys',['../group__msg_group.html#ga6ee8a007111ada293dd24ff0bab02491',1,'nats.h']]],
  ['natsmsgheader_5fset_151',['natsMsgHeader_Set',['../group__msg_group.html#gaf30b47d4217c9335919f05536e379af8',1,'nats.h']]],
  ['natsmsgheader_5fvalues_152',['natsMsgHeader_Values',['../group__msg_group.html#gae1ce9c9d82d151a3ea9dc03da048f66f',1,'nats.h']]],
  ['natsmsglist_153',['natsMsgList',['../structnats_msg_list.html',1,'natsMsgList'],['../group__types_group.html#gafd5523161ec3783e79719cb9a9a66b5b',1,'natsMsgList():&#160;nats.h']]],
  ['natsmsglist_5fdestroy_154',['natsMsgList_Destroy',['../group__msg_group.html#ga1a091d24f939d881bf04fba78b8995c2',1,'nats.h']]],
  ['natsoncompletecb_155',['natsOnCompleteCB',['../group__callbacks_group.html#ga245131e64f1d0dff7edc8ed874a07e9a',1,'nats.h']]],
  ['natsoptions_156',['natsOptions',['../group__types_group.html#gabcc48b40a81fe302188f4ee06ea9c54e',1,'nats.h']]],
  ['natsoptions_5fcreate_157',['natsOptions_Create',['../group__opts_group.html#ga61d4a0cf2fbf7d13cc910e5a00c575be',1,'nats.h']]],
  ['natsoptions_5fdestroy_158',['natsOptions_Destroy',['../group__opts_group.html#ga93d8068cd6fff53b7f8e1c403db45eb9',1,'nats.h']]],
  ['natsoptions_5fdisablenoresponders_159',['natsOptions_DisableNoResponders',['../group__opts_group.html#ga192465163abb87ad48a843b45cdf9984',1,'nats.h']]],
  ['natsoptions_5fipresolutionorder_160',['natsOptions_IPResolutionOrder',['../group__opts_group.html#ga7ca713c7532eff4d41a492e95b8822cf',1,'nats.h']]],
  ['natsoptions_5floadcatrustedcertificates_161',['natsOptions_LoadCATrustedCertificates',['../group__opts_group.html#ga2cd6563694a439b3949a31fd81103099',1,'nats.h']]],
  ['natsoptions_5floadcertificateschain_162',['natsOptions_LoadCertificatesChain',['../group__opts_group.html#ga36943e2ba53d05407cdabc4e7e96484b',1,'nats.h']]],
  ['natsoptions_5fsetallowreconnect_163',['natsOptions_SetAllowReconnect',['../group__opts_group.html#ga3d1d3cb2f2a0e23d27dd60e96d1cc91b',1,'nats.h']]],
  ['natsoptions_5fsetcatrustedcertificates_164',['natsOptions_SetCATrustedCertificates',['../group__opts_group.html#gafb30794fc2ae74b9e0bd8fb609b901c8',1,'nats.h']]],
  ['natsoptions_5fsetcertificateschain_165',['natsOptions_SetCertificatesChain',['../group__opts_group.html#gae98f0f9034e93941767ab1ae6eec2c0c',1,'nats.h']]],
  ['natsoptions_5fsetciphers_166',['natsOptions_SetCiphers',['../group__opts_group.html#ga5698f020e8eb3e7440eb073fe08ef62c',1,'nats.h']]],
  ['natsoptions_5fsetciphersuites_167',['natsOptions_SetCipherSuites',['../group__opts_group.html#ga2b7f144b011d8ce62941b608a8f324f0',1,'nats.h']]],
  ['natsoptions_5fsetclosedcb_168',['natsOptions_SetClosedCB',['../group__opts_group.html#ga44410242e73134e5bb51ef27904a9253',1,'nats.h']]],
  ['natsoptions_5fsetcustominboxprefix_169',['natsOptions_SetCustomInboxPrefix',['../group__opts_group.html#gac5173473a731a4a36d15346fedddf91f',1,'nats.h']]],
  ['natsoptions_5fsetcustomreconnectdelay_170',['natsOptions_SetCustomReconnectDelay',['../group__opts_group.html#ga3593165aa113d6736e0226ddc56b3e9d',1,'nats.h']]],
  ['natsoptions_5fsetdisconnectedcb_171',['natsOptions_SetDisconnectedCB',['../group__opts_group.html#gadc8dc0cedd91bda71d544f3dedc4a039',1,'nats.h']]],
  ['natsoptions_5fsetdiscoveredserverscb_172',['natsOptions_SetDiscoveredServersCB',['../group__opts_group.html#gab5baab507c974402ab0d8c5e8227ee65',1,'nats.h']]],
  ['natsoptions_5fseterrorhandler_173',['natsOptions_SetErrorHandler',['../group__opts_group.html#ga127ec7a8196b453947a7fa9a64096cbd',1,'nats.h']]],
  ['natsoptions_5fseteventloop_174',['natsOptions_SetEventLoop',['../group__opts_group.html#gab09491bad908dedcb323c780280733ff',1,'nats.h']]],
  ['natsoptions_5fsetexpectedhostname_175',['natsOptions_SetExpectedHostname',['../group__opts_group.html#ga0ba43ba9930df385e4781b12be9f2851',1,'nats.h']]],
  ['natsoptions_5fsetfailrequestsondisconnect_176',['natsOptions_SetFailRequestsOnDisconnect',['../group__opts_group.html#gadef4376a5e608cbc8c1a9e2b6335dc79',1,'nats.h']]],
  ['natsoptions_5fsetignorediscoveredservers_177',['natsOptions_SetIgnoreDiscoveredServers',['../group__opts_group.html#ga7e4172084520708b8c9f28e73174461c',1,'nats.h']]],
  ['natsoptions_5fsetiobufsize_178',['natsOptions_SetIOBufSize',['../group__opts_group.html#ga1a3e3abfd7ddd8aff247df8f332bbda3',1,'nats.h']]],
  ['natsoptions_5fsetlameduckmodecb_179',['natsOptions_SetLameDuckModeCB',['../group__opts_group.html#ga54dea2ffeb33779771652a7a14fc4adc',1,'nats.h']]],
  ['natsoptions_5fsetmaxpendingmsgs_180',['natsOptions_SetMaxPendingMsgs',['../group__opts_group.html#ga95510436eee06f9992ded96a44795c40',1,'nats.h']]],
  ['natsoptions_5fsetmaxpingsout_181',['natsOptions_SetMaxPingsOut',['../group__opts_group.html#gaaff89c3f41627f4b2929dbc9b82d265b',1,'nats.h']]],
  ['natsoptions_5fsetmaxreconnect_182',['natsOptions_SetMaxReconnect',['../group__opts_group.html#gab54cd2719c0b64eebd6c7b83dd2908a0',1,'nats.h']]],
  ['natsoptions_5fsetname_183',['natsOptions_SetName',['../group__opts_group.html#ga1c529d347be0fe2eec17c7f4698e283e',1,'nats.h']]],
  ['natsoptions_5fsetnkey_184',['natsOptions_SetNKey',['../group__opts_group.html#ga0290eac4665569c850468d9f00e246a0',1,'nats.h']]],
  ['natsoptions_5fsetnkeyfromseed_185',['natsOptions_SetNKeyFromSeed',['../group__opts_group.html#ga696f02e0493c00d3c1eafff45b62b68e',1,'nats.h']]],
  ['natsoptions_5fsetnoecho_186',['natsOptions_SetNoEcho',['../group__opts_group.html#ga4f694b87039cedaa65cd25656b14d1a3',1,'nats.h']]],
  ['natsoptions_5fsetnorandomize_187',['natsOptions_SetNoRandomize',['../group__opts_group.html#gaabf8763b931dcf389c83fd95d760a413',1,'nats.h']]],
  ['natsoptions_5fsetpedantic_188',['natsOptions_SetPedantic',['../group__opts_group.html#ga26f166af20de98bec67bc6cc916f769e',1,'nats.h']]],
  ['natsoptions_5fsetpinginterval_189',['natsOptions_SetPingInterval',['../group__opts_group.html#gae68fb615835364c0809555e8dc93f57e',1,'nats.h']]],
  ['natsoptions_5fsetreconnectbufsize_190',['natsOptions_SetReconnectBufSize',['../group__opts_group.html#gaa0d4b7ece8477cb9879f0dafff3456a5',1,'nats.h']]],
  ['natsoptions_5fsetreconnectedcb_191',['natsOptions_SetReconnectedCB',['../group__opts_group.html#ga26a48c8529fffa5f5d1a61c030979980',1,'nats.h']]],
  ['natsoptions_5fsetreconnectjitter_192',['natsOptions_SetReconnectJitter',['../group__opts_group.html#ga8f3df57ed8ae418d3ae6678ae5e2a5d2',1,'nats.h']]],
  ['natsoptions_5fsetreconnectwait_193',['natsOptions_SetReconnectWait',['../group__opts_group.html#ga2730f4e16e318a2ef8de98dbf6ede807',1,'nats.h']]],
  ['natsoptions_5fsetretryonfailedconnect_194',['natsOptions_SetRetryOnFailedConnect',['../group__opts_group.html#ga20946800d024b7089e73d63454d1c19f',1,'nats.h']]],
  ['natsoptions_5fsetsecure_195',['natsOptions_SetSecure',['../group__opts_group.html#gaa1f09416d443fa7a6af6b695da563eba',1,'nats.h']]],
  ['natsoptions_5fsetsendasap_196',['natsOptions_SetSendAsap',['../group__opts_group.html#ga8f06568cc3319a5a0eef9f80282034ca',1,'nats.h']]],
  ['natsoptions_5fsetservers_197',['natsOptions_SetServers',['../group__opts_group.html#gacb7e964ae54b74d972d72e118b7b8bdf',1,'nats.h']]],
  ['natsoptions_5fsettimeout_198',['natsOptions_SetTimeout',['../group__opts_group.html#ga17cd7fe41176cd98aca1184fa9352ad9',1,'nats.h']]],
  ['natsoptions_5fsettoken_199',['natsOptions_SetToken',['../group__opts_group.html#gad58a5b9dabadeebda30e952ff7b39193',1,'nats.h']]],
  ['natsoptions_5fsettokenhandler_200',['natsOptions_SetTokenHandler',['../group__opts_group.html#ga23a3b1f022112e98ddccb18b247b4426',1,'nats.h']]],
  ['natsoptions_5fseturl_201',['natsOptions_SetURL',['../group__opts_group.html#ga3f7e760214417c7d87541ecb9ab5bea5',1,'nats.h']]],
  ['natsoptions_5fsetusercredentialscallbacks_202',['natsOptions_SetUserCredentialsCallbacks',['../group__opts_group.html#ga60117450fc1f7b6f81bab455aeed7515',1,'nats.h']]],
  ['natsoptions_5fsetusercredentialsfromfiles_203',['natsOptions_SetUserCredentialsFromFiles',['../group__opts_group.html#ga59b47f7b7a19085cf8eaada9bfe5606e',1,'nats.h']]],
  ['natsoptions_5fsetuserinfo_204',['natsOptions_SetUserInfo',['../group__opts_group.html#ga5b99da7dd74aac3be962f323c3863d9e',1,'nats.h']]],
  ['natsoptions_5fsetverbose_205',['natsOptions_SetVerbose',['../group__opts_group.html#gaa16bfd09ef318af18c27a0e199681b69',1,'nats.h']]],
  ['natsoptions_5fsetwritedeadline_206',['natsOptions_SetWriteDeadline',['../group__opts_group.html#gaafda5fb8d9ee3a17bd475ceaecfac218',1,'nats.h']]],
  ['natsoptions_5fskipserververification_207',['natsOptions_SkipServerVerification',['../group__opts_group.html#ga6f804ec44adc299989fe623570679da3',1,'nats.h']]],
  ['natsoptions_5fuseglobalmessagedelivery_208',['natsOptions_UseGlobalMessageDelivery',['../group__opts_group.html#gabf060c92648b50c069f0abe7cbb06f1c',1,'nats.h']]],
  ['natsoptions_5fuseoldrequeststyle_209',['natsOptions_UseOldRequestStyle',['../group__opts_group.html#ga70aa85319933d78c0076cc862fa3e5a6',1,'nats.h']]],
  ['natssignaturehandler_210',['natsSignatureHandler',['../group__callbacks_group.html#gab786ffd670c86de0563559351305080b',1,'nats.h']]],
  ['natssock_211',['natsSock',['../nats_8h.html#af798865ac824e5959987de0fe8d07383',1,'nats.h']]],
  ['natsstatistics_212',['natsStatistics',['../group__types_group.html#ga57a4b8c7109e2773878655722ce028aa',1,'nats.h']]],
  ['natsstatistics_5fcreate_213',['natsStatistics_Create',['../group__stats_group.html#gafa923df029168f4991b77ffdd9e24877',1,'nats.h']]],
  ['natsstatistics_5fdestroy_214',['natsStatistics_Destroy',['../group__stats_group.html#ga26a04e77af8fc160adf7c33088dcf59c',1,'nats.h']]],
  ['natsstatistics_5fgetcounts_215',['natsStatistics_GetCounts',['../group__stats_group.html#gad85f5ffb4272713f6cc6d988e6d4e75f',1,'nats.h']]],
  ['natsstatus_216',['natsStatus',['../status_8h.html#a36c934157b663b7b5fb5d6609c897c80',1,'status.h']]],
  ['natsstatus_5fgettext_217',['natsStatus_GetText',['../group__status_group.html#ga4a83c4a08f1e4dd9451c1a88b6a4254e',1,'nats.h']]],
  ['natssubscription_218',['natsSubscription',['../group__types_group.html#ga87158ec63b4f90f69e20451624ea01d8',1,'nats.h']]],
  ['natssubscription_5fautounsubscribe_219',['natsSubscription_AutoUnsubscribe',['../group__sub_group.html#ga09f285de2746a6e27fc66efd60bd3116',1,'nats.h']]],
  ['natssubscription_5fclearmaxpending_220',['natsSubscription_ClearMaxPending',['../group__sub_group.html#gafe31911d8372db401d33856465421710',1,'nats.h']]],
  ['natssubscription_5fdestroy_221',['natsSubscription_Destroy',['../group__sub_group.html#ga50a95dd96e9b714201679a015d62832f',1,'nats.h']]],
  ['natssubscription_5fdrain_222',['natsSubscription_Drain',['../group__sub_group.html#ga26c9736289d326fb7d6df7e2a0df72ab',1,'nats.h']]],
  ['natssubscription_5fdraincompletionstatus_223',['natsSubscription_DrainCompletionStatus',['../group__sub_group.html#ga9834bd02f67a25ac084d5ad71e146019',1,'nats.h']]],
  ['natssubscription_5fdraintimeout_224',['natsSubscription_DrainTimeout',['../group__sub_group.html#ga9c26a3f9584e7804060a48ec1b7e2a68',1,'nats.h']]],
  ['natssubscription_5ffetch_225',['natsSubscription_Fetch',['../group__js_sub_group.html#gafc5e0d2269bd23b4d5fb7f3b05278e50',1,'nats.h']]],
  ['natssubscription_5ffetchrequest_226',['natsSubscription_FetchRequest',['../group__js_sub_group.html#ga676292505e7fde8688cfd886b79a10ed',1,'nats.h']]],
  ['natssubscription_5fgetconsumerinfo_227',['natsSubscription_GetConsumerInfo',['../group__js_sub_group.html#gaae716a1431db065744c079b71a9f4c2e',1,'nats.h']]],
  ['natssubscription_5fgetdelivered_228',['natsSubscription_GetDelivered',['../group__sub_group.html#ga476b7276d0b7f9946834d2bb2423e955',1,'nats.h']]],
  ['natssubscription_5fgetdropped_229',['natsSubscription_GetDropped',['../group__sub_group.html#ga24f1636869e26661ce62c9c9f4d80823',1,'nats.h']]],
  ['natssubscription_5fgetid_230',['natsSubscription_GetID',['../group__sub_group.html#ga5a029a784c0a7f8b5800b48cc995db20',1,'nats.h']]],
  ['natssubscription_5fgetmaxpending_231',['natsSubscription_GetMaxPending',['../group__sub_group.html#ga0abc5d9afbc6b0c9c5adaf533904c968',1,'nats.h']]],
  ['natssubscription_5fgetpending_232',['natsSubscription_GetPending',['../group__sub_group.html#gaca6262e2ef842caa701a9f233db72707',1,'nats.h']]],
  ['natssubscription_5fgetpendinglimits_233',['natsSubscription_GetPendingLimits',['../group__sub_group.html#ga786bb458981274fe717f266bd3b96d96',1,'nats.h']]],
  ['natssubscription_5fgetsequencemismatch_234',['natsSubscription_GetSequenceMismatch',['../group__js_sub_group.html#ga0daed9f0d2d00cb14314ecc180a6fa84',1,'nats.h']]],
  ['natssubscription_5fgetstats_235',['natsSubscription_GetStats',['../group__sub_group.html#ga12b60cdb3aca7329edebc480ae86bfab',1,'nats.h']]],
  ['natssubscription_5fgetsubject_236',['natsSubscription_GetSubject',['../group__sub_group.html#gadd4872b9fc5678a73f9ab04ce8428432',1,'nats.h']]],
  ['natssubscription_5fisvalid_237',['natsSubscription_IsValid',['../group__sub_group.html#ga5e6454bbc7a90b9694112d45bd8de903',1,'nats.h']]],
  ['natssubscription_5fnextmsg_238',['natsSubscription_NextMsg',['../group__sub_group.html#ga6538a5d78dfb0f16514b94c8e74c11af',1,'nats.h']]],
  ['natssubscription_5fnodeliverydelay_239',['natsSubscription_NoDeliveryDelay',['../group__sub_group.html#ga38f1e41fc7619101fc4aa52014dd5428',1,'nats.h']]],
  ['natssubscription_5fqueuedmsgs_240',['natsSubscription_QueuedMsgs',['../group__sub_group.html#ga8a37b2d5290da3aecc05483d79e7e254',1,'nats.h']]],
  ['natssubscription_5fsetoncompletecb_241',['natsSubscription_SetOnCompleteCB',['../group__sub_group.html#gaea632f845d473e7461b134c0e7bf4077',1,'nats.h']]],
  ['natssubscription_5fsetpendinglimits_242',['natsSubscription_SetPendingLimits',['../group__sub_group.html#ga68a7cea89e75c529a7dd3bb77303dda4',1,'nats.h']]],
  ['natssubscription_5funsubscribe_243',['natsSubscription_Unsubscribe',['../group__sub_group.html#gaee87f8be0e6c2a4693ba2cea070583ba',1,'nats.h']]],
  ['natssubscription_5fwaitfordraincompletion_244',['natsSubscription_WaitForDrainCompletion',['../group__sub_group.html#ga0408c9b6e4ad4078ac0267656ace222d',1,'nats.h']]],
  ['natstokenhandler_245',['natsTokenHandler',['../group__callbacks_group.html#ga4b02de70fe9380d184fd01d87527f499',1,'nats.h']]],
  ['natsuserjwthandler_246',['natsUserJWTHandler',['../group__callbacks_group.html#ga258b30458134be90f17315c037f34b7b',1,'nats.h']]],
  ['nextbysubject_247',['NextBySubject',['../structjs_direct_get_msg_options.html#a16ce7908a3d1690b8ae8bc22350ac238',1,'jsDirectGetMsgOptions']]],
  ['noack_248',['NoAck',['../structjs_stream_config.html#a8e358fbc569a1c6d49c704e6dbdf8609',1,'jsStreamConfig']]],
  ['nowait_249',['NoWait',['../structjs_fetch_request.html#ae251eebb1998a39fe3b898302b58293d',1,'jsFetchRequest']]],
  ['numackpending_250',['NumAckPending',['../structjs_consumer_info.html#a882bebeb7af80fcce088afdf2c98de50',1,'jsConsumerInfo']]],
  ['numdeleted_251',['NumDeleted',['../structjs_stream_state.html#acbec2f01830b56cb4c0bf54ae5170e51',1,'jsStreamState']]],
  ['numdelivered_252',['NumDelivered',['../structjs_msg_meta_data.html#a9a50965fac061a9728b160702d3f56ff',1,'jsMsgMetaData']]],
  ['numpending_253',['NumPending',['../structjs_consumer_info.html#aeaefd5a500996013b1ce13d8872e869b',1,'jsConsumerInfo::NumPending()'],['../structjs_msg_meta_data.html#a02f1bbd37e9650ed6bfda0210f038e30',1,'jsMsgMetaData::NumPending()']]],
  ['numredelivered_254',['NumRedelivered',['../structjs_consumer_info.html#a932bf14ebb9ce167af8975e3b1f8d001',1,'jsConsumerInfo']]],
  ['numsubjects_255',['NumSubjects',['../structjs_stream_state.html#aaa43db17641826e7c6ecc1954f641960',1,'jsStreamState']]],
  ['numwaiting_256',['NumWaiting',['../structjs_consumer_info.html#a57e4a4139310c50a1f3d51af67197af0',1,'jsConsumerInfo']]]
];
